==> openGion_dev_5.1.1.2.zip: opengion/uap/webapps/gf/src/org/opengion/hayabusa/report2/ProcessFactory.java <==
/*
 * Copyright (c) 2009 The openGion Project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.opengion.hayabusa.report2;

import java.io.File;
import java.io.IOException;

import org.opengion.fukurou.util.AbstractObjectPool;
import org.opengion.fukurou.util.Cleanable;
import org.opengion.fukurou.util.FileUtil;
import org.opengion.hayabusa.common.HybsSystem;
import org.opengion.hayabusa.common.SystemManager;

/**
 * Sofficeのプロセスを管理するファクトリクラスです。
 * プロセスプールの実装は、AbstractObjectPoolを継承して実装されています。
 *
 * プロセスの初期生成数は0です。最大生成数は、システムリソースのREPORT_MAX_PROCESS_COUNTで
 * 定義されます。また、生存時間は、REPORT_PROCESS_ALIVEで定義されています。
 *
 * プロセスを全て終了するには、clearメソッドを呼び出します。
 * clearメソッドは、Cleanableインターフェースの実装として組み込まれ、SytemManagerに登録されるため、
 * Tomcat終了時に、自動的にプロセスが終了されます。
 * 但し、貸し出し中(処理中)のプロセスは、AbstractObjecgPoolの実装から、終了されないため、別の方法で
 * 明示的にkillする必要があります
 *
 * @version  4.0
 * @author   Hiroki Nakamura
 * @since    JDK5.0,
 */
public final class ProcessFactory {

	/**
	 * プロセスプール
	 */
	private static ProcessPool pp = new ProcessPool() ;

	/** Cleanable インターフェースによる初期化処理 */
	static {
		Cleanable clr = new Cleanable() {
			public void clear() {
				ProcessFactory.clear();
			}
		};
		SystemManager.addCleanable( clr );
	}

	/**
	 * デフォルトコンストラクターをprivateにして、
	 * オブジェクトの生成をさせないようにする。
	 */
	private ProcessFactory() {
	}

	/**
	 * OpenOfficeのプロセスを生成します。
	 * 
	 * @return sofficeのプロセス
	 */
	public static SOfficeProcess newInstance() {
		return pp.newInstance();
	}

	/**
	 * OpenOfficeのプロセスをリリースします。
	 * 
	 * @param   soffice
	 */
	public static void release( final SOfficeProcess soffice ) {
		pp.release( soffice );
	}

	/**
	 * OpenOfficeのプロセスをクローズします。
	 * 
	 * @param   soffice
	 */
	public static void remove( final SOfficeProcess soffice ) {
		pp.remove( soffice );
	}

	/**
	 * プールされているOpenOfficeのプロセスを全てクローズします。
	 */
	public static void clear() {
		pp.clear();
	}
	
	/**
	 * 全てのsoffice.binプロセスをKILLします。
	 * アプリケーションの終了処理で実行します。
	 * OS名がWindowsを含む場合はtaskkill、それ以外の場合はkillallします。
	 * 又、プロセス終了後にコピーされた設定ファイルを削除します。
	 * 
	 * @og.rev 4.3.0.0 (2008/07/18) 追加
	 * @og.rev 4.3.0.0 (2008/07/22) 設定ファイルの削除を追加
	 * @og.rev 4.3.5.0 (2009/02/01) Exception をそれぞれのExceptionに分けて捕らえる。
	 */
	public static void kill() {
		try {
			final String osName = HybsSystem.sys( "OS_INFO" ); //System.getProperty("os.name");
//			if( osName.indexOf( "Windows" ) != -1 ){
//				// 4.3.0.0 (2008/07/18) Windoesのtaskkillを利用してsoffice.binのタスクを強制終了します。
//				new ProcessBuilder( "cmd.exe","/c","taskkill","/F","/IM","soffice.bin" ).start().waitFor();
//			}
//			else{
//				// 4.3.0.0 (2008/07/24) Windowsではない場合はkillallコマンド
//				new ProcessBuilder( "killall","-9","-w","soffice.bin" ).start().waitFor();
//			}
			if( osName.indexOf( "Windows" ) >= 0 ){
				// 4.3.0.0 (2008/07/18) Windoesのtaskkillを利用してsoffice.binのタスクを強制終了します。
				new ProcessBuilder( "cmd.exe","/c","taskkill","/F","/IM","soffice.bin" ).start().waitFor();
			}
			else{
				// 4.3.0.0 (2008/07/24) Windowsではない場合はkillallコマンド
				new ProcessBuilder( "killall","-9","-w","soffice.bin" ).start().waitFor();
			}

			// 4.3.0.0 (2008/07/22) 設定ファイル（SOfficeProcessでディレクトリを設定）を全削除します。
			FileUtil.deleteFiles( new File( SOfficeProcess.ENV_DIR ) );
		}
//		catch( Exception ex ) {
//			ex.printStackTrace();
//		}
		catch( IOException ex ) {
			ex.printStackTrace();
		}
		catch( InterruptedException ex ) {
			ex.printStackTrace();
		}
		catch( RuntimeException ex ) {
			ex.printStackTrace();
		}
	}

	/**
	 * 
	 * @return  現在の状態
	 */
	public static String information() {
		return pp.toString();
	}
	
	/**
	 * ProcessPool は、AbstractObjectPool を継承した オブジェクトプールです。
	 * 
	 * OpenOfficeのプロセスをプールします。
	 *
	 * @version  4.0
	 * @author   Hiroki Nakamura
	 * @since    JDK5.0,
	 */
	protected static class ProcessPool extends AbstractObjectPool<SOfficeProcess> {
		// 環境ファイル作成の識別用
		private int count = 0;

		/**
		 * 初期処理を行います。
		 */
		protected ProcessPool() {
			init( 0, HybsSystem.sysInt( "REPORT_MAX_PROCESS_COUNT")
					, true, HybsSystem.sysInt( "REPORT_PROCESS_ALIVE" ) );
		}

		/**
		 * soffieのプロセスオブジェクトを作成します。
		 *
		 * @og.rev 4.3.5.0 (2009/02/01) Exception ではなく、RuntimeException に変更
		 *
		 * @return OpenOfficeのプロセス
		 */
		protected SOfficeProcess createInstance() {
			SOfficeProcess soffice = null;
			try {
				soffice = new SOfficeProcess( "env_" + count );
				soffice.bootstrap();
				count++;
			}
//			catch( Exception ex ) {
			catch( RuntimeException ex ) {
				System.out.println( "[ERROR]OOo:Failed to Connect Soffice! " + ex.getMessage() );
			}
			return soffice;
		}

		/**
		 * オブジェクトプールから削除するときに呼ばれます。
		 * このメソッドで各オブジェクトごとの終了処理を行います。
		 *
		 * @param soffice OpenOfficeのプロセス
		 */
		protected void objectFinal( final SOfficeProcess soffice ) {
			soffice.close();
		}
	}
}

==> openGion_dev_5.1.7.0.zip: opengion/uap/webapps/gf/src/org/opengion/hayabusa/report2/ProcessFactory.java <==
/*
 * Copyright (c) 2009 The openGion Project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.opengion.hayabusa.report2;

import java.io.File;
import java.io.IOException;

import org.opengion.fukurou.util.AbstractObjectPool;
import org.opengion.fukurou.util.Cleanable;
import org.opengion.fukurou.util.FileUtil;
import org.opengion.hayabusa.common.HybsSystem;
import org.opengion.hayabusa.common.SystemManager;

/**
 * Sofficeのプロセスを管理するファクトリクラスです。
 * プロセスプールの実装は、AbstractObjectPoolを継承して実装されています。
 *
 * プロセスの初期生成数は0です。最大生成数は、システムリソースのREPORT_MAX_PROCESS_COUNTで
 * 定義されます。また、生存時間は、REPORT_PROCESS_ALIVEで定義されています。
 *
 * プロセスを全て終了するには、clearメソッドを呼び出します。
 * clearメソッドは、Cleanableインターフェースの実装として組み込まれ、SytemManagerに登録されるため、
 * Tomcat終了時に、自動的にプロセスが終了されます。
 * 但し、貸し出し中(処理中)のプロセスは、AbstractObjecgPoolの実装から、終了されないため、別の方法で
 * 明示的にkillする必要があります
 *
 * @version  4.0
 * @author   Hiroki Nakamura
 * @since    JDK5.0,
 */
public final class ProcessFactory {

	/**
	 * プロセスプール
	 */
	private static ProcessPool pp = new ProcessPool() ;

	/** Cleanable インターフェースによる初期化処理 */
	static {
		Cleanable clr = new Cleanable() {
			public void clear() {
				ProcessFactory.clear();
			}
		};
		SystemManager.addCleanable( clr );
	}

	/**
	 * デフォルトコンストラクターをprivateにして、
	 * オブジェクトの生成をさせないようにする。
	 */
	private ProcessFactory() {
	}

	/**
	 * OpenOfficeのプロセスを生成します。
	 * 
	 * @return sofficeのプロセス
	 */
	public static SOfficeProcess newInstance() {
		return pp.newInstance();
	}

	/**
	 * OpenOfficeのプロセスをリリースします。
	 * 
	 * @param   soffice
	 */
	public static void release( final SOfficeProcess soffice ) {
		pp.release( soffice );
	}

	/**
	 * OpenOfficeのプロセスをクローズします。
	 * 
	 * @param   soffice
	 */
	public static void remove( final SOfficeProcess soffice ) {
		pp.remove( soffice );
	}

	/**
	 * プールされているOpenOfficeのプロセスを全てクローズします。
	 */
	public static void clear() {
		pp.clear();
	}
	
	/**
	 * 全てのsoffice.binプロセスをKILLします。
	 * アプリケーションの終了処理で実行します。
	 * OS名がWindowsを含む場合はtaskkill、それ以外の場合はkillallします。
	 * 又、プロセス終了後にコピーされた設定ファイルを削除します。
	 * 
	 * @og.rev 4.3.0.0 (2008/07/18) 追加
	 * @og.rev 4.3.0.0 (2008/07/22) 設定ファイルの削除を追加
	 * @og.rev 4.3.5.0 (2009/02/01) Exception をそれぞれのExceptionに分けて捕らえる。
	 */
	public static void kill() {
		try {
			final String osName = HybsSystem.sys( "OS_INFO" ); //System.getProperty("os.name");
//			if( osName.indexOf( "Windows" ) != -1 ){
//				// 4.3.0.0 (2008/07/18) Windoesのtaskkillを利用してsoffice.binのタスクを強制終了します。
//				new ProcessBuilder( "cmd.exe","/c","taskkill","/F","/IM","soffice.bin" ).start().waitFor();
//			}
//			else{
//				// 4.3.0.0 (2008/07/24) Windowsではない場合はkillallコマンド
//				new ProcessBuilder( "killall","-9","-w","soffice.bin" ).start().waitFor();
//			}
			if( osName.indexOf( "Windows" ) >= 0 ){
				// 4.3.0.0 (2008/07/18) Windoesのtaskkillを利用してsoffice.binのタスクを強制終了します。
				new ProcessBuilder( "cmd.exe","/c","taskkill","/F","/IM","soffice.bin" ).start().waitFor();
			}
			else{
				// 4.3.0.0 (2008/07/24) Windowsではない場合はkillallコマンド
				new ProcessBuilder( "killall","-9","-w","soffice.bin" ).start().waitFor();
			}

			// 4.3.0.0 (2008/07/22) 設定ファイル（SOfficeProcessでディレクトリを設定）を全削除します。
			FileUtil.deleteFiles( new File( SOfficeProcess.ENV_DIR ) );
		}
//		catch( Exception ex ) {
//			ex.printStackTrace();
//		}
		catch( IOException ex ) {
			ex.printStackTrace();
		}
		catch( InterruptedException ex ) {
			ex.printStackTrace();
		}
		catch( RuntimeException ex ) {
			ex.printStackTrace();
		}
	}

	/**
	 * 
	 * @return  現在の状態
	 */
	public static String information() {
		return pp.toString();
	}
	
	/**
	 * ProcessPool は、AbstractObjectPool を継承した オブジェクトプールです。
	 * 
	 * OpenOfficeのプロセスをプールします。
	 *
	 * @version  4.0
	 * @author   Hiroki Nakamura
	 * @since    JDK5.0,
	 */
	protected static class ProcessPool extends AbstractObjectPool<SOfficeProcess> {
		// 環境ファイル作成の識別用
		private int count = 0;

		/**
		 * 初期処理を行います。
		 */
		protected ProcessPool() {
			init( 0, HybsSystem.sysInt( "REPORT_MAX_PROCESS_COUNT")
					, true, HybsSystem.sysInt( "REPORT_PROCESS_ALIVE" ) );
		}

		/**
		 * soffieのプロセスオブジェクトを作成します。
		 *
		 * @og.rev 4.3.5.0 (2009/02/01) Exception ではなく、RuntimeException に変更
		 * @og.rev 5.1.7.0 (2010/06/01) TCP接続対応
		 *
		 * @return OpenOfficeのプロセス
		 */
		protected SOfficeProcess createInstance() {
			SOfficeProcess soffice = null;
			try {
				// 5.1.7.0 (2010/06/01) TCP接続対応
//				soffice = new SOfficeProcess( "env_" + count );
				if( "TCP".equalsIgnoreCase( HybsSystem.sys( "REPORT_OOO_CONN_TYPE" ) ) ) {
					soffice = new SOfficeProcessTcp( "env_" + count, HybsSystem.sysInt( "REPORT_OOO_MIN_PORT" ) );
				}
				else {
					soffice = new SOfficeProcess( "env_" + count );
				}
				soffice.bootstrap();

				count++;
			}
//			catch( Exception ex ) {
			catch( RuntimeException ex ) {
				System.out.println( "[ERROR]OOo:Failed to Connect Soffice! " + ex.getMessage() );
			}
			return soffice;
		}

		/**
		 * オブジェクトプールから削除するときに呼ばれます。
		 * このメソッドで各オブジェクトごとの終了処理を行います。
		 *
		 * @param soffice OpenOfficeのプロセス
		 */
		protected void objectFinal( final SOfficeProcess soffice ) {
			soffice.close();
		}
	}
}
